lpc: Rename point_to_memory to lpc_map_memory

Change-Id: Iee32689e1c222a422aadf217d1fb0c817250de6b
Signed-off-by: Andrew Jeffery <andrew@aj.id.au>
diff --git a/lpc.c b/lpc.c
index a2fc6e6..2c8b00d 100644
--- a/lpc.c
+++ b/lpc.c
@@ -142,12 +142,12 @@
 }
 
 /*
  * point_to_memory() - Point the lpc bus mapping to the reserved memory region
  * @context:	The mbox context pointer
  *
  * Return:	0 on success otherwise negative error code
  */
-int point_to_memory(struct mbox_context *context)
+int lpc_map_memory(struct mbox_context *context)
 {
 	struct aspeed_lpc_ctrl_mapping map = {
 		.window_type = ASPEED_LPC_CTRL_WINDOW_MEMORY,
@@ -142,12 +142,12 @@
 
 /*
- * point_to_memory() - Point the lpc bus mapping to the reserved memory region
+ * lpc_map_memory() - Point the lpc bus mapping to the reserved memory region
  * @context:	The mbox context pointer
  *